polyfemos.parser.resources — polyfemos 0.3.29 documentation

# polyfemos.parser.resources

Contains all commands, special characters and reserved variables for ‘*.conf’ files

`polyfemos.parser.resources.` `SYMBOLS`

`polyfemos.parser.resources.` `CMDS`

`polyfemos.parser.resources.` `VARS`

copyright

  2019, University of Oulu, Sodankyla Geophysical Observatory

license

  GNU Lesser General Public License v3.0 or later (https://spdx.org/licenses/LGPL-3.0-or-later.html)